# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import lilt
from lilt.models.project_status import ProjectStatus  # noqa: E501
from lilt.rest import ApiException

class TestProjectStatus(unittest.TestCase):
    """ProjectStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProjectStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = lilt.models.project_status.ProjectStatus()  # noqa: E501
        if include_optional :
            return ProjectStatus(
                id = 21902, 
                num_source_words = 6039, 
                num_words_confirmed = 151, 
                num_words_reviewed = 12, 
                time_elapsed = 2980000, 
                time_elapsed_translation = 33487, 
                time_elapsed_research = 912348, 
                time_elapsed_review = 66521, 
                resources = [
                    lilt.models.resource_status.ResourceStatus(
                        email = 'joe.strummer@lilt.com', 
                        name = 'Joe Strummer', 
                        num_words_confirmed = 151, 
                        num_words_new = 12, 
                        num_words_fuzzy = 24, 
                        num_words_exact = 56, 
                        num_words_reviewed = 182, 
                        time_elapsed = 1172000, 
                        time_elapsed_translation = 1172000, 
                        time_elapsed_research = 1172000, 
                        time_elapsed_review = 1172000, 
                        num_segments_confirmed = 25, 
                        num_segments_reviewed = 30, )
                    ]
            )
        else :
            return ProjectStatus(
        )

    def testProjectStatus(self):
        """Test ProjectStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
