# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import lilt
from lilt.api.converter_config_api import ConverterConfigApi  # noqa: E501
from lilt.rest import ApiException


class TestConverterConfigApi(unittest.TestCase):
    """ConverterConfigApi unit test stubs"""

    def setUp(self):
        self.api = lilt.api.converter_config_api.ConverterConfigApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_converter_config(self):
        """Test case for add_converter_config

        Add Converter Config  # noqa: E501
        """
        pass

    def test_delete_converter_config(self):
        """Test case for delete_converter_config

        Delete Converter Config  # noqa: E501
        """
        pass

    def test_delete_filter_mapping(self):
        """Test case for delete_filter_mapping

        Delete Filter Mapping  # noqa: E501
        """
        pass

    def test_edit_filter_mapping(self):
        """Test case for edit_filter_mapping

        Add Filter Mapping  # noqa: E501
        """
        pass

    def test_get_converter_config_by_id(self):
        """Test case for get_converter_config_by_id

        Fetch Converter Config by Id  # noqa: E501
        """
        pass

    def test_get_converter_configs(self):
        """Test case for get_converter_configs

        List Converter Configs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
